@@ -46,6 +46,9 @@ def add_need(
     template=None,
     pre_template=None,
     post_template=None,
+    is_external=False,
+    external_url=None,
+    external_css="external_link",
     **kwargs
 ):
     """
@@ -58,6 +61,10 @@ def add_need(
     If an entry is found in ``kwags``, which *is not* specified in the configuration or registered e.g. via
     ``add_extra_option``, an exception is raised.
 
+    If ``is_external`` is set to ``True``, no node will be created.
+    Instead the need is referencing an external url.
+    Used mostly for :ref:`needs_external_needs` to integrate and reference needs from external documentation.
+
     **Usage**:
 
     Normally needs get created during handling of a specialised directive.
@@ -106,6 +113,9 @@ def add_need(
     :param template: Template name to use for the content of this need
     :param pre_template: Template name to use for content added before need
     :param post_template: Template name to use for the content added after need
+    :param is_external: Is true, no node is created and need is referencing external url
+    :param external_url: URL as string, which is used as target if ``is_external`` is ``True``
+    :param external_css: CSS class name as string, which is set for the <a> tag.
 
     :return: node
     """
@@ -123,8 +133,8 @@ def add_need(
         if ntype["directive"] == need_type:
             type_name = ntype["title"]
             type_prefix = ntype["prefix"]
-            type_color = ntype["color"]
-            type_style = ntype["style"]
+            type_color = ntype["color"] or "#000000"  # if no color set up user in config
+            type_style = ntype["style"] or "node"  # if no style set up user in config
             found = True
             break
     if not found:
@@ -158,7 +168,12 @@ def add_need(
         )
 
     # Calculate target id, to be able to set a link back
-    target_node = nodes.target("", "", ids=[need_id], refid=need_id)
+    if is_external:
+        target_node = None
+        external_url = external_url
+    else:
+        target_node = nodes.target("", "", ids=[need_id], refid=need_id)
+        external_url = None
 
     # Handle status
     # Check if status is in needs_statuses. If not raise an error.
@@ -234,6 +249,7 @@ def add_need(
         "docname": docname,
         "lineno": lineno,
         "target_node": target_node,
+        "external_url": external_url,
         "content_node": None,  # gets set after rst parsing
         "type": need_type,
         "type_name": type_name,
@@ -257,6 +273,10 @@ def add_need(
         "is_part": False,
         "is_need": True,
         "parent_need": None,
+        "is_external": is_external or False,
+        "external_css": external_css or "external_link",
+        "is_modified": False,  # needed by needextend
+        "modifications": 0,  # needed by needextend
     }
     needs_extra_options = env.config.needs_extra_options.keys()
     _merge_extra_options(needs_info, kwargs, needs_extra_options)
@@ -293,7 +313,7 @@ def add_need(
             links = _read_in_links(links_string)
 
         needs_info[link_type["option"]] = links
-        needs_info["{}_back".format(link_type["option"])] = set()
+        needs_info["{}_back".format(link_type["option"])] = []
 
         if "copy" not in link_type.keys():
             link_type["copy"] = False
@@ -314,8 +334,6 @@ def add_need(
         # Overwrite current content
         content = new_content
         needs_info["content"] = new_content
-    else:
-        new_content = None
 
     # pre_template
     if needs_info["pre_template"]:
@@ -331,6 +349,9 @@ def add_need(
     else:
         post_content = None
 
+    if needs_info["is_external"]:
+        return []
+
     if needs_info["hide"]:
         return [target_node]
 
@@ -371,6 +392,59 @@ def add_need(
     return return_nodes
 
 
+def add_external_need(
+    app,
+    need_type,
+    title,
+    id=None,
+    external_url=None,
+    external_css="external_link",
+    content="",
+    status=None,
+    tags=None,
+    links_string=None,
+    **kwargs
+):
+    """
+    Adds an external need from an external source.
+    This need does not have any representation in the current documentation project.
+    However, it can be linked and filtered.
+    It's reference will open a link to another, external  sphinx documentation project.
+
+    It return an empty list (without any nodes), so no nodes will be added to the document.
+
+    :param app: Sphinx application object.
+    :param need_type: Name of the need type to create.
+    :param title: String as title.
+    :param id: ID as string. If not given, a id will get generated.
+    :param external_url: URL as string, which shall be used as link to the original need source
+    :param content: Content as single string.
+    :param status: Status as string.
+    :param tags: Tags as single string.
+    :param links_string: Links as single string.
+    :param external_css: CSS class name as string, which is set for the <a> tag.
+    :param kwargs:
+
+    :return: Empty list
+    """
+
+    kwargs["state"] = None
+    kwargs["docname"] = None
+    kwargs["lineno"] = None
+    kwargs["need_type"] = need_type
+    kwargs["id"] = id
+    kwargs["content"] = content
+    kwargs["title"] = title
+    kwargs["status"] = status
+    kwargs["tags"] = tags
+    kwargs["links_string"] = links_string
+    kwargs["is_external"] = True
+    kwargs["external_url"] = external_url
+    kwargs["external_css"] = external_css
+
+    return add_need(app=app, **kwargs)
+
+
 def _prepare_template(app, needs_info, template_key):
     template_folder = app.config.needs_template_folder
     if not os.path.isabs(template_folder):
